##  Updates from Inventory
Diagrams always show the view the way it was saved last time. This might differ from the current view of the architecture if changes to the architecture happened after the diagram was saved. Fact sheets and relations will only be removed from the canvas if you manually apply these updates.
**Note**
The data flow and Free Draw diagram data is kept up to date with the inventory, so any changes made to the inventory are automatically indicated in the diagram. However, it's important to note that while updates are indicated, they are not automatically applied.
Updates appear in the top right corner of both the viewer and the editor. A count of the available updates for the diagram is also displayed. To view more details for all available updates in the diagram, click Updates.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274425d97a441014921c8ba547d325ec_LowRes.png)
**Tip**
To hide inventory updates in view mode, hover over the diagram to display the toolbar. Click Hide Inventory Updates to remove the update icons from the current view. If you navigate to a different diagram or refresh the page, the update icons will reappear.
To apply updates, switch to the editor. There, you can click the Updates button to view all updates available for the diagram. Select the updates that you want to apply and click Apply Updates.
Labels and views are updated automatically unless Auto Update View Colors and Labels is toggled off. It will also remove from the modal all updates related to updating fact sheet view colors and labels. This setting is enabled by default on new diagrams but can be turned off and on as needed.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27525c757a4410149236e1759fa48b44_LowRes.png)
**Note**
If auto-update is applied after the diagram is opened, and the user doesn't have the need to save it, then they can click Exit and Discard changes, and the diagram will be in the same state as before the auto-update.
**Note**
When viewing a diagram, the "Updating diagram" spinner icon indicates data is currently loading for views and/or an automatic update is in progress in the backend. Once the update concludes, the spinner disappears, and the view toolbar becomes functional again. Throughout the spinner display, other functionalities such as zooming, changing the viewport, clicking on diagrams or fact sheets, and using filters remain accessible.
This allows users to swiftly view and interact with diagrams on the dashboard and in the viewer without waiting for the backend updates to finish.
**Note**
The diagrams can be exported to other formats, such as PDF, SVG, PNG, HTML embed code, and XML file, which is compatible with [Flowchart Maker & Online Diagram Software![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fdraw.io%2F "http://draw.io/"). Check the documentation on exporting diagrams for more details.
**Caution**
Fact sheet and relation creation features are only available in [Free Draw](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD). Although we envision enabling the creation of applications and interfaces directly from the data flow editor, this is currently not yet available.
